function [tobs,y,R] = gen_obs(t,x_t,freq_obs,H,var_obs)
% [tobs,y,R] = gen_obs(t,x_t,freq_obs,H)

% This function generates [linear] observations from a nature run
% Input:    - t, the time array of the truth [Nsteps,1]
%           - x_t, the true run [Nsteps, N variables]
%           - freq_obs, observation frequency (in model t steps)
%           - H, the observation matrix
%           - var_obs, the observational error variance (diagonal R)
% Output:   - tobs, the time array of the observations
%           - y, the observations
%           - R, the observational error covariance matrix

% some settings
tstep_truth = t(2)-t(1);
tstep_obs = freq_obs*tstep_truth;

% the size of the observation operator (matrix) gives us the number of
% state variables and observations
[L,N] = size(H);

% the time array for obs (and coincides with the assimilation window time)
tobs=(0:tstep_obs:max(t))';

% initialize observations array
y = NaN(length(tobs),L);

% the covariance matrix (in this case it is diagonal)
R = var_obs*eye(L,L);

% the cycle that generates the observations 
for j=2:length(tobs) % at time 0 there are no obs
 x_aux = x_t(freq_obs*(j-1)+1,:)';
 eps_aux = sqrt(R)*randn(L,1);
 y_aux = H*x_aux + eps_aux;
 y(j,:) = y_aux';
end




